@@ -142,9 +142,6 @@ chroots (with <tt>qemu-user-static</tt> installed).
     def mbd_get_system_schroot_conf_file(self):
         return os.path.join("/etc/schroot/chroot.d", self.mbd_get_name() + ".conf")
 
-    def mbd_get_sudoers_workaround_file(self):
-        return os.path.join(self.mbd_get_path(), "sudoers_workaround")
-
     def mbd_get_pre_sequence(self):
         "Subclasses may implement this to do define an extra preliminary sequence."
         LOG.debug("{c}: No pre-sequence defined.".format(c=self))
@@ -158,26 +155,15 @@ chroots (with <tt>qemu-user-static</tt> installed).
               "--variant=buildd",
               "--keyring={k}".format(k=self.mbd_get_keyring_file()),
               "--arch={a}".format(a=self.architecture.name),
-              "--include=sudo",
               self.source.codename,
               self.mbd_get_tmp_dir(),
               self.source.mbd_get_archive().url],
-             ["/bin/umount", "-v", os.path.join(self.mbd_get_tmp_dir(), "proc"), os.path.join(self.mbd_get_tmp_dir(), "sys")]),
-
-            (["/bin/cp", "--verbose", self.mbd_get_sudoers_workaround_file(), "{m}/etc/sudoers".format(m=self.mbd_get_tmp_dir())],
-             [])] + self.mbd_get_backend().mbd_get_post_sequence() + [
+             ["/bin/umount", "-v", os.path.join(self.mbd_get_tmp_dir(), "proc"), os.path.join(self.mbd_get_tmp_dir(), "sys")])] + self.mbd_get_backend().mbd_get_post_sequence() + [
 
             (["/bin/cp", "--verbose", self.mbd_get_schroot_conf_file(), self.mbd_get_system_schroot_conf_file()],
              ["/bin/rm", "--verbose", self.mbd_get_system_schroot_conf_file()])]
 
     def mbd_prepare(self, request):
-        """
-        .. note:: SUDO WORKAROUND for http://bugs.debian.org/cgi-bin/bugreport.cgi?bug=608840
-
-            Includes '--include=sudo' and all handling of 'sudoers_workaround_file' below.
-
-            .. seealso:: :py:class:`~mini_buildd.builder.Build`
-        """
         mini_buildd.misc.mkdirs(os.path.join(self.mbd_get_path(), mini_buildd.setup.CHROOT_LIBDIR))
 
         # Set personality
@@ -190,13 +176,6 @@ chroots (with <tt>qemu-user-static</tt> installed).
             except:
                 self.personality = "linux"
 
-        mini_buildd.misc.ConfFile(
-            self.mbd_get_sudoers_workaround_file(),
-            """\
-{u} ALL=(ALL) ALL
-{u} ALL=NOPASSWD: ALL
-""".format(u=os.getenv("USER"))).save()
-
         mini_buildd.misc.ConfFile(
             self.mbd_get_schroot_conf_file(),
             """\
@@ -240,11 +219,31 @@ personality={p}
                                            "--user={u}".format(u=user)] +
                                           args)
 
+    def mbd_check_sudo_workaround(self, request):
+        """
+        mini-buildd <= 1.0.4 created chroots with a "sudo workaround" for bug
+        https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=607228.
+
+        Suche chroots must be recreated, and no longer used.
+        """
+        has_sudo_workaround = False
+        try:
+            self._mbd_schroot_run(["--directory=/", "--", "grep", "^{u}".format(u=os.getenv("USER")), "/etc/sudoers"])
+            has_sudo_workaround = True
+        except:
+            MsgLog(LOG, request).info("{c}: Ok, no sudo workaround found.".format(c=self))
+
+        if has_sudo_workaround:
+            raise Exception("Chroot has sudo workaround (created with versions <= 1.0.4): Please run 'Remove' + 'PCA' on this chroot to re-create!")
+
     def mbd_backend_check(self, request):
         "Subclasses may implement this to do extra backend checks."
         MsgLog(LOG, request).info("{c}: No backend check implemented.".format(c=self))
 
     def mbd_check(self, request):
+        # Check for the old sudo workaround (chroots created by mini-buildd <= 1.0.4)
+        self.mbd_check_sudo_workaround(request)
+
         # Basic function checks
         self._mbd_schroot_run(["--info"])
 
